=head1 NAME PkgDebug.pm

PkgDebug.pm - The PkgDebug module is used for printing debugging, warning, and
error messages for the pkg project. The PkgDebug module is not an object, so
do not treat it like one. Calls to the methods defined below should be
qualified with the package name ( like PkgDebug::function() ).

$Id: PkgDebug.pm,v 1.5 1999/06/25 22:04:12 gomberg Exp $

=cut

package PkgDebug;
use     Carp;

# Global static variable to store the debug level
my $DEBUG_LEVEL = 0;

########################################################################

=head1 Public Functions

=head2 set_debug_level( $level )

    IN: The integer value (1-9) to use for debug messages.
        Note- this value should be set only once during
        command line processing.
   OUT: Return value is not defined.
EFFECT: Changes the value of the static global debug variable.

=cut

sub set_debug_level {
    $DEBUG_LEVEL = shift;
    
    $DEBUG_LEVEL = 3 unless (defined $DEBUG_LEVEL);
}

########################################################################

=head2 debug( $level, @messages )

    IN: An integer value (1-9) defining the detail level of the
        debug message (1=top level, 9=very detailed), and the debug
        message(s).
   OUT: Return value is not defined.
EFFECT: Prints a DEBUG message to STDERR (and newline) if the the
        detail level is less than or equal to the debug level specified
        on the command line.

=cut

sub debug {
    my( $level, @messages ) = @_;

    if( $level <= $DEBUG_LEVEL ) {
	my $message = shift( @messages );
	print STDERR "DEBUG $message\n";
	foreach $message ( @messages ) {
	    print STDERR "      $message\n";
	}
    }
}

########################################################################

=head2 warn( @messages )

    IN: A warning message(s) to be printed.
   OUT: Return value is not defined.
EFFECT: Prints a WARNING message(s) and newline to STDERR.

=cut

sub warn {
    my @messages = @_;
    my $message = shift( @messages );

    print STDERR "WARN  $message\n";
    foreach $message ( @messages ) {
	print STDERR "      $message\n";
    }
}

########################################################################

=head2 error( @messages )

    IN: An error message(s).
   OUT: Function does not return! Program will exit.
EFFECT: Prints an ERROR message to STDERR and exits the program
        with the line number where the error occured.

=cut

sub error {
    my @messages = @_;
    my $endmess = pop( @messages );

    if( @messages ) {
	my $message = shift( @messages );
	print STDERR "ERROR $message\n";
	foreach $message ( @messages ) {
	    print STDERR "      $message\n";
	}
	croak "      $endmess";
    }
    else {
	croak "ERROR $endmess";
    }
}

1;
